/* THIS SAMPLE CODE IS PROVIDED AS IS AND IS SUBJECT TO ALTERATIONS. FUJITSU */
/* MICROELECTRONICS ACCEPTS NO RESPONSIBILITY OR LIABILITY FOR ANY ERRORS OR */
/* ELIGIBILITY FOR ANY PURPOSES                                              */
/*                 (C) Fujitsu Microelectronics Europe GmbH                  */
/*****************************************************************************
 *    MB91360 Series routine to change PLL settings V1.6
 *
 *
 *  DESCRIPTION:    Switchs PLL smooth  on MB91360 Starterkit
 *				See README.TXT for more details
 *
 *  History
 * 30.07.99 V1.0 Andreas Grimm
 * 		1st demo version
 *  10.01.01 V1.1 Andreas Grimm
 * 		values for DIVR0,DIR1,CLKR passed as parameter to the routine
 *  02.02.01 V1.2 Andreas Grimm
 * 		value for FMWT passed as parameter to the routine
 *  27.06.01 V1.3 Andreas Grimm
 *  	when oscillator is clock source set 1 wait state to FMWT
 *  13.07.01 V1.4 Andreas Grimm
 *  	treating the clock modulator
 *  14.08.01 V1.5 Andreas Grimm
 *  	routine optimised and bugs (saving ICR's, set to sleep mode when clock source is changed) fixed
 *  10.04.02 V1.6 Andreas Grimm
 *  	routine ported from assembler to C-language
 *  30.04.02 V1.7 Andreas Grimm
 *  	sequence changed to set sleep-mode (rmw-instruction splitted)
 *  (C) Fujitsu Mikroelektronics GmbH
 *****************************************************************************/

#include "MB91362.H"	/* include all IO-Register definitions */

void Put_PS(unsigned long);
unsigned int Get_PS(void);


void switch_pll(unsigned char register_CLKR, unsigned char register_DIVR0,unsigned char register_DIVR1, unsigned char register_FWMT)
{
unsigned char local_register_TBCR;
unsigned long local_register_ICR[12],*ptr,local_PS;
unsigned char count;



/*	save status register	*/
local_PS = Get_PS();

/*disable all interrupts*/
__DI();

/*save TBCR */
local_register_TBCR = TBCR;

/* save all ICR's and set lowest priority to each ICR to disable all interrupts*/

ptr=(unsigned long*) 0x440;
for (count=0;count<=11;count++)
	{
	local_register_ICR[count]= *ptr;
	*ptr++ = 0x1F1F1F1F;
	}

/* disable clock modulator */
if(CMCR & 0x0001)
	{
	CMCR &= 0xFFBF;
	CMCR &= 0xFFAC;
	}

/* disable TBC interrupt */
TBCR &= 0x3F;				

/*   set R-Bus to PLL /16 MHz : */
DIVR0 = 0x0F;

/*   set ext Bus to PLL /16 MHz : */
DIVR1 = 0xF0;
/*	set interrupt level of tbc */
ICR31 = 30;

/* if PLL clock source, then set clock source -> oscillator */
if(CLKR &0x02)
	{
/*	configuration and start of TBC */
	CTBR = 0xA5;
	CTBR = 0x5A;
	TBCR = 0x40;


#pragma asm
/*  set clock source -> oscillator */
	stm0 (r0,r1,r2,r3)
	ldi:20 #_clkr,R3
	ldub @r3,r2
	ldi:8 #0xFC,r1
	and r1,r2

/*	go to SLEEP mode */
	ldi:8	#0x50,r1
	ldi:20	#_stcr,r0
	stb	r1,@r0
	stb r2,@r3     ; deselect PLL as clock source
	ldm0 (r0,r1,r2,r3)
#pragma endasm


/* now sleeping...*/
	while(!(TBCR & 0x80));

/* disable tbc interrupt */
	TBCR = 0;
	}
/* endif PLL clock source, then set clock source -> oscillator */


/*PLL not clock source */


/* switch off PLL */

CLKR &= 0xF8;

/* set 1 wait states to FWMT */
FMWT = 0x01;
/*   prepare configuration main PLL : */
/* mask the multiplier for CLKR-register; if register_CLKR !=0, then switch PLL on*/
if (register_CLKR &= 0x70)
	{
	CLKR &= 0x8F;
	CLKR |= register_CLKR;
/* set parameter value -> FWMT */		
	FMWT= register_FWMT;
/* configuration and start of TBC; no interrupt; timer underflow is polled */
	CTBR =0xA5;
	CTBR =0x5A;
	TBCR = 0;	/* TBIF=0,TBIE=0,TBC=000,SYNCR/SYNCS=0*/

/* switch on PLL*/	
	CLKR |=0x04;
	
	while(!(TBCR & 0x80)); /*awaiting stabilisation time*/

/* PLL lock time elapsed */
/* configuration and start of TBC */

	CTBR =0xA5;
	CTBR =0x5A;
	TBCR = 0x40;	/* TBIF=0,TBIE=1,TBC=000,SYNCR/SYNCS=0*/
	
#pragma asm
/*  clock source -> PLL */
	stm0 (r0,r1,r2,r3)
	ldi:20 #_clkr, R3
	ldub @r3,r2
	ldi:8 #0x02,r1
	or r1,r2    

/*	go to SLEEP mode */
	ldi:8	#0x50,r1
	ldi:20	#_stcr,r0
	stb	r1,@r0
	stb r2,@r3     ; select PLL as clock source
	ldm0 (r0,r1,r2,r3)
#pragma endasm


/* now sleeping...*/
	while(!(TBCR & 0x80));

/* TBT off */
	TBCR = 0;
	}
/* end switch PLL on*/

/*   set R-Bus frequency :  */
DIVR0 = register_DIVR0;

/*   set ext.Bus frequency : */
DIVR1 = register_DIVR1;

/* end SMOOTH_PLL */

/* restore ICR's*/
ptr=(unsigned long*) 0x440;
for (count=0;count<=11;count++)
	{
	 *ptr++ = local_register_ICR[count];
	}
TBCR = local_register_TBCR;

/* restore status register */

Put_PS(local_PS);
}


#pragma asm
_Get_PS:
	mov ps,r4
	ret

_Put_PS:
	mov r4,ps
	ret
#pragma endasm	
