;*******************************************************
;       Definition of Interrupt Vectors
;       (MB91F362 Architecture)
;*******************************************************

;       Three steps to define Interrupt-Vectors :
;       =========================================
;
;       1. Create an interrupt service routine (ISR) 
;          in a C-module which looks like this :
;           void __interrupt ihTimer16(void) { ... }
;
;       2. Insert the ISR-name (with underscore) in this 
;          file ("Import ISR Names") like this :
;          .import _ihTimer16   
;
;       3. Locate the appropriate interrupt vector below
;          and replace the "uninitial_int" with your ISR :
;           .ORG     0x0FFF9C       ; reload timer #0
;           .DATA    _ihTimer16 

;*******************************************************

;*******************************************************
;*
;*  This sample file, originally delivered from Fujitsu,
;*  was modified by Segger Microcontroller Systeme GmbH
;*  to be used with embOS:
;*
;*  1.  Defines for OS_UART added to control assembly
;*
;*  2.  embOS interrupt functions were imported
;*
;*  3.  embOS interrupt vector for embOS timer was added
;*      Per default we used reload timer #0
;*
;*  4.  embOS UART-interrupt vectors were added.
;*      These are used for communication to embOSView
;*      Per default, we use UART 0
;*      To disable UART for embOSView, you have to set
;*      OS_UART=-1 as tool option for compiler AND assembler.
;*
;*  When simulator should be used, you have to set the
;*  Tool Option for assembler to define SIMULATOR = 1
;*  which then also automatically removes UART interrupt
;*  vectors from the vector table
;*
;*******************************************************

;*******************************************************
;**
;** 1. Modification by Segger: default settings and 
;**    defines for Simulator and usage of UART for embOSView

#ifndef SIMULATOR       ; May be defined as assembler option 
  #define SIMULATOR 0   
#endif

#if SIMULATOR           
  #define OS_UART (-1)  ; Can not be used with simulator
#endif

#ifndef OS_UART
  #define OS_UART 0     ; Defaults to UART 0 for embOSView 
#endif

;** End of 1. Modification by Segger
;**
;*******************************************************

;*******************************************************

;   Import ISR Names :

       .import _OS_COM_ISR_rx, _OS_COM_ISR_tx
       .import _OS_ISR_Tick  ; embOS timer tick interrupt handler

#ifdef OSTEST
       .import _OSTEST_ISR0  ; embOS test program interrupt handler
#endif       

;*******************************************************


        .SECTION        INTVECT,const, align= 4
        .GLOBAL         _vectors

; 176 vectors for software interrupt by INT-instruction

        .DATA 	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 

        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 

        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 

        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 

        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 

        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 

        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 

        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 

        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 

        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 

        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 

        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 

        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 

        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 

        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 

        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 

        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 

        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
        .DATA	 uninitial_int		; software interrupt by INT-instruction 
	

		.SKIP 0x34					; reserved for system
        .DATA	 0xFFFFFFFF			; security vector 0xFFFFFFFF

		.SKIP 0x8
        .DATA	 uninitial_int		; ICR47, delayed interrupt
        .DATA	 uninitial_int		; ICR46, DMA interrupt
        .DATA	 uninitial_int		; ICR45, RTC interrupt
        .DATA	 uninitial_int		; ICR44, alarm comperator interrupt
        .DATA	 uninitial_int		; ICR43, I2C interrupt

#if OS_UART == 2
        .DATA	 _OS_COM_ISR_tx		; ICR42, Tx interrupt for embOSView
        .DATA	 _OS_COM_ISR_rx		; ICR41, Rx interrupt for embOSView
#else
        .DATA	 uninitial_int		; ICR42, UART2 Tx interrupt
        .DATA	 uninitial_int		; ICR41, UART2 Rx interrupt
#endif

#if OS_UART == 1
        .DATA	 _OS_COM_ISR_tx		; ICR42, Tx interrupt for embOSView
        .DATA	 _OS_COM_ISR_rx		; ICR41, Rx interrupt for embOSView
#else

        .DATA	 uninitial_int		; ICR40, UART1 Tx interrupt
        .DATA	 uninitial_int		; ICR39, UART1 Rx interrupt
#endif

#if OS_UART == 0
        .DATA	 _OS_COM_ISR_tx		; ICR42, Tx interrupt for embOSView
        .DATA	 _OS_COM_ISR_rx		; ICR41, Rx interrupt for embOSView
#else

        .DATA	 uninitial_int		; ICR38, UART0 Tx interrupt
        .DATA	 uninitial_int		; ICR37, UART0 Rx interrupt
#endif

        .DATA	 uninitial_int		; ICR36, Sound generator interrupt
        .DATA	 uninitial_int		; ICR35, SIO1 interrupt
        .DATA	 uninitial_int		; ICR34, SIO0 Rx interrupt
        .DATA	 uninitial_int		; ICR33, free running counter 1  interrupt
        .DATA	 uninitial_int		; ICR32, free running counter 0 interrupt
        .DATA	 uninitial_int		; ICR31, time base counter interrupt
        .DATA	 uninitial_int		; ICR30, ADC interrupt
        .DATA	 uninitial_int		; ICR29, output compare 2/3 interrupt
        .DATA	 uninitial_int		; ICR28, input capture 2/3 interrupt
        .DATA	 uninitial_int		; ICR27, output compare 0/1 interrupt
        .DATA	 uninitial_int		; ICR26, input capture 0/1 interrupt
        .DATA	 uninitial_int		; ICR25, reload timer 5 interrupt
        .DATA	 uninitial_int		; ICR24, reload timer 4 interrupt
        .DATA	 uninitial_int		; ICR23, reload timer 3 interrupt
        .DATA	 uninitial_int		; ICR22, PPG 6/7 interrupt
        .DATA	 uninitial_int		; ICR21, PPG 5/4 interrupt
        .DATA	 uninitial_int		; ICR20, PPG 2/3 interrupt
        .DATA	 uninitial_int		; ICR19, PPG 0/1 interrupt
        .DATA	 uninitial_int		; ICR18, CAN 3 TX/NS interrupt
        .DATA	 uninitial_int		; ICR17, CAN 3 RX interrupt
        .DATA	 uninitial_int		; ICR16, CAN 2 TX/NS interrupt
        .DATA	 uninitial_int		; ICR15, CAN 2 RX interrupt
        .DATA	 uninitial_int		; ICR14, CAN 1 TX/NS interrupt
        .DATA	 uninitial_int		; ICR13, CAN 1 RX interrupt
        .DATA	 uninitial_int		; ICR12, CAN 0 TX/NS interrupt
        .DATA	 uninitial_int		; ICR11, CAN 0 RX interrupt
        .DATA	 uninitial_int		; ICR10, reload timer 2 interrupt

#ifdef OSTEST
        .DATA    _OSTEST_ISR0       ; reload-timer 1 used for embOS test program
#else
        .DATA	 uninitial_int		; ICR09, reload timer 1 interrupt
#endif
;        .DATA	 uninitial_int 		; ICR08, reload timer 0 interrupt
        .DATA    _OS_ISR_Tick        ; embOS timer tick handler in RtosInit.c

        .DATA	 uninitial_int		; ICR07, external interrupt 7
        .DATA	 uninitial_int		; ICR06, external interrupt 6
        .DATA	 uninitial_int		; ICR05, external interrupt 5
        .DATA	 uninitial_int		; ICR04, external interrupt 4
        .DATA	 uninitial_int		; ICR03, external interrupt 3
        .DATA	 uninitial_int		; ICR02, external interrupt 2
        .DATA	 uninitial_int		; ICR01, external interrupt 1
        .DATA	 uninitial_int		; ICR00, external interrupt 0	; User0-Button (INT0) is reserved for "ABORT PROGRAM"

