/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2008  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS version: 3.60d                                         *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : sbrk.c                          (for Fujitsu FR CPUs)
Purpose : Implements a heap and checks for the heap limit
          This function is based on the FR compiler documatation
          Feel free to modify this function according your needs.
--------  END-OF-HEADER  ---------------------------------------------
*/

#define HEEP_SIZE 4*1024

static long brk_siz = 0;

#if HEEP_SIZE
  typedef int _heep_t;
  #define ROUNDUP(s) (((s)+sizeof(_heep_t)-1)& ~ (sizeof(_heep_t)-1))
  static  int _heep[ROUNDUP(HEEP_SIZE)/sizeof(_heep_t)];
  #define _heep_size ROUNDUP(HEEP_SIZE)

#else
  extern char
  _heep_t
  *_heep;
  extern long _heep_size;
#endif

/*********************************************************************
*
*       sbrk()
*/

extern char *sbrk(int size) {
  if (brk_siz + size > _heep_size || brk_siz + size < 0) {
    return((char*)-1);
  }
  brk_siz += size;
  return( (char *)_heep + brk_siz - size);
}

/****** End of File *************************************************/
